import { ComponentClass } from 'react';
import Taro, { Component } from '@tarojs/taro';
import { View, Image, Text } from '@tarojs/components';

import UserBoxBg from '../../images/home/img_bg@2x.png';
import ArrowIcon from '../../images/home/icon_dingdan@2x.png';
import HairDryerBg from '../../images/home/img_chuifeng_bg@2x.png';
import HairDryerArr from '../../images/home/icon_chuifeng_right@2x.png';
import AnnouncementBg from '../../images/home/img_gonggao_bg@2x.png';
import MoreIcon from '../../images/home/icon_more_right@2x.png';
import SettingIcon from '../../images/home/icon_shezhi@2x.png';
import HBeanIcon from '../../images/home/icon_chuifengdou@2x.png';
import TBeanIcon from '../../images/home/icon_tongyongdou@2x.png';
import UserHeaderM from '../../images/home/img_boy_touxiang@2x.png';
import UserHeaderF from '../../images/home/img_girl_touxiang@2x.png';

import './Home.scss';
import { connect } from '@tarojs/redux';
import {
  UserState,
  updateUserInfo,
  INITIAL_STATE as userINitState,
} from '../../store/rootReducers/userinfo';
import { fetchBeanCount } from '../../api/bean';
import { fetchAnn, SectionItem } from '../../api/announcement';
import { appLogout } from '../../api/customer';

type PageStateProps = {
  userinfo: UserState;
};
type PageDispatchProps = {
  updateUserInfo: (e: UserState) => void;
};

type PageState = {
  barMenuVisiable: boolean;
  commBean: number;
  hairDryerBean: number;
  annItem: SectionItem;
};
type IProps = PageStateProps & PageDispatchProps;

interface Home {
  props: IProps;
  state: PageState;
}
@connect(
  ({ userinfo }) => ({
    userinfo,
  }),
  dispatch => ({
    updateUserInfo(entity: UserState) {
      dispatch(updateUserInfo(entity));
    },
  }),
)
class Home extends Component {
  constructor(props) {
    super(props);
    this.state = {
      barMenuVisiable: false,
      commBean: 0.0,
      hairDryerBean: 0.0,
      annItem: {
        id: 0,
        styleType: '',
        name: '',
        titleTypeRemark: '',
        titleType: '',
        titleContent: '',
        sort: 0,
        updateTime: 0,
        itemsCount: 0,
        items: [],
      },
    };
  }

  componentWillMount() {
    this.getInitData();
  }
  getInitData() {
    const { userinfo } = this.props;
    fetchBeanCount({
      id: userinfo.customerId,
      areaId: userinfo.areaId,
      customerPhone: userinfo.customerPhone,
      serviceIdList: [],
    })
      .then(res => {
        const data = res.data;
        let commBeanItem = data.find(item => item.serviceId === '1');
        let hairDryerBeanItem = data.find(item => item.serviceId === '4');
        let commBean = commBeanItem ? commBeanItem.money : 0.0;
        let hairDryerBean = hairDryerBeanItem ? hairDryerBeanItem.money : 0.0;
        this.setState({
          commBean,
          hairDryerBean,
        });
      })
      .catch(console.error);
    fetchAnn({
      campusId: userinfo.areaId,
      customerId: userinfo.customerId,
    })
      .then(res => {
        if (res) {
          this.setState({
            annItem: res,
          });
        }
      })
      .catch(err => {
        console.error(err);
      });
  }

  goSetting() {
    Taro.navigateTo({
      url: '/pages/UserSetting/UserSetting',
    });
  }
  goFeedback() {
    this.toggleBarMenu();
    Taro.navigateTo({
      url: '/pages/Feedback/Feedback',
    });
  }
  goAnn(id: number) {
    Taro.navigateTo({
      url: '/pages/Announcement/Announcement?sectionId=' + id,
    });
  }

  goOrder() {
    Taro.navigateTo({
      url: '/pages/Order/OrderList/OrderList',
    });
  }

  goBarCode() {
    Taro.navigateTo({
      url: '/pages/BarCode/BarCode',
    });
  }

  toggleBarMenu() {
    this.setState(({ barMenuVisiable }: PageState) => ({
      barMenuVisiable: !barMenuVisiable,
    }));
  }
  logoutHandle() {
    const { updateUserInfo } = this.props;
    appLogout()
      .then(() => {
        updateUserInfo(userINitState);
        Taro.redirectTo({
          url: '/pages/index/index',
        });
      })
      .catch(console.log);
  }
  formatePhone = (phone: string) => {
    let newPhone = phone.replace(/([0-9]{3})([0-9]{4})([0-9]{4})/, '$1****$3');
    return newPhone;
  };
  geAnnDetail(id: number, title: string) {
    console.log(id);
    Taro.navigateTo({
      url: `/pages/Content/Content?id=${id}`,
    });
  }
  render() {
    const { userinfo } = this.props;
    const { commBean, hairDryerBean, annItem, barMenuVisiable } = this.state;
    return (
      <View className='Home'>
        {barMenuVisiable ? (
          <View>
            <View className='mask' onClick={this.toggleBarMenu} />
            <View className='Home-BarMenu'>
              <View className='Home-BarMenu-Content'>
                <View onClick={this.goFeedback}>意见反馈</View>
                <View onClick={this.logoutHandle}>切换账号</View>
              </View>
            </View>
          </View>
        ) : null}
        <View className='Home-UserBox'>
          <Image
            className='Home-UserBox-Setting'
            src={SettingIcon}
            onClick={this.toggleBarMenu}
          />
          <Image className='bg' src={UserBoxBg} />
          <View className='Home-UserBox-info'>
            <View className='Home-UserBox-other'>
              <View className='Home-UserBox-name'>{userinfo.customerName}</View>
              <View className='Home-UserBox-tel'>
                {this.formatePhone(userinfo.customerPhone)}
              </View>
              <View className='Home-UserBox-addr'>{userinfo.areaName}</View>
            </View>
            {userinfo.customerSex === '2' ? (
              <Image
                className='Home-UserBox-headimg'
                src={UserHeaderF}
                onClick={this.goSetting}
              />
            ) : (
              <Image
                className='Home-UserBox-headimg'
                src={UserHeaderM}
                onClick={this.goSetting}
              />
            )}
          </View>
          <View className='Home-UserBox-line' />
          <View className='Home-UserBox-Bean'>
            <View className='Home-UserBox-BeanItem'>
              <Image className='Home-UserBox-BeanIcon' src={HBeanIcon} />
              <Text>吹风豆：</Text>
              <Text className='Home-UserBox-BeanCount'>{hairDryerBean}</Text>
            </View>
            <View className='Home-UserBox-BeanItem'>
              <Image className='Home-UserBox-BeanIcon' src={TBeanIcon} />
              <Text>通用豆：</Text>
              <Text className='Home-UserBox-BeanCount'>{commBean}</Text>
            </View>
          </View>
          <View className='Home-UserBox-Order'>
            <Text className='Home-UserBox-Order-text'>我的订单</Text>
            <View className='Home-UserBox-Order-right' onClick={this.goOrder}>
              <Image className='Home-UserBox-Order-icon' src={ArrowIcon} />
            </View>
          </View>
        </View>
        <View className='Home-HairDryer' onClick={this.goBarCode}>
          <Image className='bg' src={HairDryerBg} />
          <View className='Home-HairDryer-shadow' />
          <View className='Home-HairDryer-text'>
            吹风
            <Image className='Home-HairDryer-arrow' src={HairDryerArr} />
          </View>
        </View>
        {annItem.id ? (
          <View className='Home-Announcement'>
            <Image className='bg' src={AnnouncementBg} />
            <View className='Home-Announcement-title'>
              <Text>最新公告</Text>
              <View
                className='Home-Announcement-more'
                onClick={() => this.goAnn(annItem.id)}>
                更多
                <Image className='more-icon' src={MoreIcon} />
              </View>
            </View>
            {annItem.items.length && (
              <View
                className='Home-Announcement-Content'
                onClick={() =>
                  this.geAnnDetail(annItem.items[0].id, annItem.items[0].title)
                }>
                <Text>{annItem.items[0].title}</Text>
                <Text className='ContentDate'>
                  {annItem.items[0].updateTime}
                </Text>
              </View>
            )}
          </View>
        ) : null}
      </View>
    );
  }
}

export default Home as ComponentClass<PageStateProps, PageState>;
